==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/it/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(visibile anche a chi non è membro dello space)',
    '<strong>Delete</strong> content?' => '<strong>Eliminare</strong> i contenuti?',
    '<strong>Move</strong> content' => '<strong>Sposta</strong> contenuto',
    '<strong>Permalink</strong> to this post' => '<strong>Link permanente</strong> a questo articolo',
    'Activated' => 'Attivato',
    'Add a member to notify' => 'Aggiungi i partecipanti che riceveranno notifica',
    'Add tag...' => 'Aggiungi Tag...',
    'Archived' => 'Archiviato',
    'Attach Files' => 'Allega file',
    'Back to stream' => 'Torna allo stream',
    'Cancel' => 'Annulla',
    'Cancel Edit' => 'Annulla modifiche',
    'Change to "Private"' => 'Rendi privato',
    'Change to "Public"' => 'Rendi pubblico',
    'Comments are locked' => 'I commenti sono bloccati',
    'Comments are unlocked' => 'I commenti sono sbloccati',
    'Configure' => 'Configura',
    'Confirm' => 'Conferma',
    'Content' => 'Contenuti',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Contenuto Tag assegnato con un valore non valido di contentcontainer_id.',
    'Content has been moved to {spacename}' => 'Il contenuto é stato spostato in {spacename}',
    'Could not find requested content!' => 'Impossibile trovare il contenuto richiesto!',
    'Created at:' => 'Creato il:',
    'Created by me' => 'Creato da me',
    'Creation time' => 'Data di creazione',
    'Delete' => 'Cancella',
    'Deleted' => 'Eliminata',
    'Edit' => 'Modifica',
    'Enable' => 'Abilita',
    'Filter' => 'Filtro',
    'I\'m involved' => 'Dove sono coinvolto',
    'Invalid content id given!' => 'Il Content id fornito non è valido!',
    'Invalid request method!' => 'Metodo di richiesta non valido!',
    'Invalid space selection.' => 'Spazio selezionato non valido',
    'Last update' => 'Ultimo aggiornamento',
    'Last updated {time}' => 'Ultimo aggiornamento {time}',
    'Load more' => 'Caricane altri',
    'Lock comments' => 'Blocca commenti',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Raggiunto il numero massimo di elementi aggiuntivi. <br> Puoi aggiungere fino a {count} elementi contemporaneamente.',
    'Move content' => 'Sposta contentuto',
    'Move to archive' => 'Archivia',
    'New Updates Available!' => 'Nuovi aggiornamenti disponibili!',
    'No matches with your selected filters!' => 'Nessun risultato con i filtri che hai selezionato!',
    'No tags found for the given query' => 'Nessun tag trovato per la query data',
    'None' => 'Nessuno',
    'Nothing here yet!' => 'Non c\'è ancora niente qui!',
    'Notify members' => 'Notifica i partecipanti',
    'Permalink' => 'Link permanente',
    'Pin to top' => 'Appunta in cima',
    'Pinned' => 'In evidenza',
    'Private' => 'Privato',
    'Public' => 'Pubblico',
    'Select type...' => 'Seleziona il tipo...',
    'Specify who can see this content.' => 'Specifica chi può vedere questo contenuto.',
    'Submit' => 'Invia',
    'Tag' => 'Tag',
    'Target Space' => 'Spazio di destinazione',
    'The author of this content is not allowed to create private content within the selected space.' => 'L\'autore di questo contenuto non può creare contenuti privati nello spazio selezionato.',
    'The author of this content is not allowed to create public content within the selected space.' => 'L\'autore di questo contentuto non può creare contenuti pubblici nello spazio selezionato.',
    'The author of this content is not allowed to create this type of content within this space.' => 'L\'autore di questo contenuto non è autorizzato a creare questo tipo di contenuto all\'interno di questo spazio.',
    'The content can\'t be moved to its current space.' => 'Il contenuto non può essere spostaro dal suo spazio attuale.',
    'The content has been archived.' => 'Il contenuto è stato archiviato.',
    'The content has been deleted.' => 'Il contenuto è stato eliminato.',
    'The content has been unarchived.' => 'Il contenuto non è stato ripristinato.',
    'The given name is already in use.' => 'Il nome fornito è già in uso.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Il modulo {moduleName} non è attivato nello spazio selezionato.',
    'This action is disabled!' => 'Questa azione è disattivata!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Il contenuto non può essere spostato perchè è mancante il settaggio dell\'id modulo',
    'This content type can\'t be moved.' => 'Il contentuto non può essere spostato.',
    'This space is archived.' => 'Questo spazio è archiviato.',
    'This space is not visible!' => 'Questo spazio non è visibile!',
    'Topics' => 'Argomenti',
    'Turn off notifications' => 'Disattiva notifiche',
    'Turn on notifications' => 'Attiva notifiche',
    'Unarchive' => 'Ripristina',
    'Unlock comments' => 'Sblocca commenti',
    'Unpin' => 'Scollega',
    'Updated' => 'Aggiornato',
    'Visible also to unregistered users' => 'Visibile anche dagli utenti non registrati',
    'Visible only to you' => 'Visibile solo a te',
    'Visible to all Space members' => 'Visibile a tutti i membri dello spazio',
    'Visible to all signed in users' => 'Visibile a tutti gli utenti collegati',
    'Visible to friends of {displayName}' => 'Visibile a tutti gli amici di {displayName}',
    'Visible to you and {displayName}' => 'Visibile a te e a {displayName}',
    'Visible to your friends' => 'Visibile ai tuoi amici',
    'With attachments' => 'Con allegati',
    'You cannot block the space owner!' => 'Non puoi bloccare il proprietario dello spazio!',
    'You cannot block the user of the same container!' => 'Non puoi bloccare l\'utente.',
    'You cannot block yourself!' => 'Non puoi bloccare te stesso',
    'You do not have the permission to move this content to the given space.' => 'Non hai il permesso di spostare il contenuto nello spazio indicato.',
    'You do not have the permission to move this content.' => 'Non hai il permesso di spostare questo contenuto.',
    'Your last edit state has been saved!' => 'La tua ultima modifica è stato salvata!',
    'in' => 'in',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Cannot notify the author.' => '',
    'Create as draft' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Hidden' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
];

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/content/messages/it/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(visibile anche a chi non è membro dello space)',
    '<strong>Delete</strong> content?' => '<strong>Eliminare</strong> i contenuti?',
    '<strong>Move</strong> content' => '<strong>Sposta</strong> contenuto',
    '<strong>Permalink</strong> to this post' => '<strong>Link permanente</strong> a questo articolo',
    '<strong>Scheduling</strong> Options' => 'Opzioni di <strong>Programmazione</strong>',
    'Activate scheduling' => 'Attivare la programmazione',
    'Add a member to notify' => 'Aggiungi i partecipanti che riceveranno notifica',
    'Add tag...' => 'Aggiungi Tag...',
    'Archived' => 'Archiviato',
    'Attach Files' => 'Allega file',
    'Back to stream' => 'Torna allo stream',
    'Cancel' => 'Annulla',
    'Cancel Edit' => 'Annulla modifiche',
    'Cannot notify the author.' => 'Non è possibile notificare l\'autore.',
    'Change to "Private"' => 'Rendi privato',
    'Change to "Public"' => 'Rendi pubblico',
    'Comments are locked' => 'I commenti sono bloccati',
    'Comments are unlocked' => 'I commenti sono sbloccati',
    'Configure' => 'Configura',
    'Confirm' => 'Conferma',
    'Content' => 'Contenuti',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Contenuto Tag assegnato con un valore non valido di contentcontainer_id.',
    'Content has been moved to {spacename}' => 'Il contenuto é stato spostato in {spacename}',
    'Could not find requested content!' => 'Impossibile trovare il contenuto richiesto!',
    'Create as draft' => 'Creare come bozza',
    'Created at:' => 'Creato il:',
    'Created by me' => 'Creato da me',
    'Creation time' => 'Data di creazione',
    'Delete' => 'Cancella',
    'Deleted' => 'Eliminata',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => 'Si desidera eliminare questo contenuto, compresi tutti i commenti e gli allegati? <br><br>Nota bene: se una voce di flusso è stata creata utilizzando un modulo, anche il contenuto originale a cui questa voce è collegata verrà eliminato.',
    'Draft' => 'Bozza',
    'Edit' => 'Modifica',
    'Enable' => 'Abilita',
    'Enabled' => 'Attivato',
    'Filter' => 'Filtro',
    'Hidden' => 'Nascosto',
    'I\'m involved' => 'Dove sono coinvolto',
    'Invalid content id given!' => 'Il Content id fornito non è valido!',
    'Invalid request method!' => 'Metodo di richiesta non valido!',
    'Invalid space selection.' => 'Spazio selezionato non valido',
    'Last update' => 'Ultimo aggiornamento',
    'Last updated {time}' => 'Ultimo aggiornamento {time}',
    'Load more' => 'Caricane altri',
    'Lock comments' => 'Blocca commenti',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Raggiunto il numero massimo di elementi aggiuntivi. <br> Puoi aggiungere fino a {count} elementi contemporaneamente.',
    'Move content' => 'Sposta contentuto',
    'Move to archive' => 'Archivia',
    'New Updates Available!' => 'Nuovi aggiornamenti disponibili!',
    'No matches with your selected filters!' => 'Nessun risultato con i filtri che hai selezionato!',
    'No tags found for the given query' => 'Nessun tag trovato per la query data',
    'None' => 'Nessuno',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => 'Nota: per motivi tecnici potrebbe verificarsi un ritardo di alcuni minuti.',
    'Nothing here yet!' => 'Non c\'è ancora niente qui!',
    'Notify members' => 'Notifica i partecipanti',
    'Permalink' => 'Link permanente',
    'Pin to top' => 'Appunta in cima',
    'Pinned' => 'In evidenza',
    'Private' => 'Privato',
    'Public' => 'Pubblico',
    'Publish draft' => 'Pubblicare la bozza',
    'Save as draft' => 'Salva come bozza',
    'Save scheduling' => 'Salvataggio della programmazione',
    'Schedule publication' => 'Pubblicazione del programma',
    'Scheduled for {dateTime}' => 'Programmato per {dateTime}',
    'Select type...' => 'Seleziona il tipo...',
    'Specify who can see this content.' => 'Specifica chi può vedere questo contenuto.',
    'Submit' => 'Invia',
    'Tag' => 'Tag',
    'Target Space' => 'Spazio di destinazione',
    'The author of this content is not allowed to create private content within the selected space.' => 'L\'autore di questo contenuto non può creare contenuti privati nello spazio selezionato.',
    'The author of this content is not allowed to create public content within the selected space.' => 'L\'autore di questo contentuto non può creare contenuti pubblici nello spazio selezionato.',
    'The author of this content is not allowed to create this type of content within this space.' => 'L\'autore di questo contenuto non è autorizzato a creare questo tipo di contenuto all\'interno di questo spazio.',
    'The content can\'t be moved to its current space.' => 'Il contenuto non può essere spostaro dal suo spazio attuale.',
    'The content cannot be published!' => 'Il contenuto non può essere pubblicato!',
    'The content has been archived.' => 'Il contenuto è stato archiviato.',
    'The content has been deleted.' => 'Il contenuto è stato eliminato.',
    'The content has been successfully published.' => 'Il contenuto è stato pubblicato con successo.',
    'The content has been unarchived.' => 'Il contenuto non è stato ripristinato.',
    'The given name is already in use.' => 'Il nome fornito è già in uso.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Il modulo {moduleName} non è attivato nello spazio selezionato.',
    'This action is disabled!' => 'Questa azione è disattivata!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Il contenuto non può essere spostato perchè è mancante il settaggio dell\'id modulo',
    'This content type can\'t be moved.' => 'Il contentuto non può essere spostato.',
    'This space is archived.' => 'Questo spazio è archiviato.',
    'This space is not visible!' => 'Questo spazio non è visibile!',
    'Topics' => 'Argomenti',
    'Turn off notifications' => 'Disattiva notifiche',
    'Turn on notifications' => 'Attiva notifiche',
    'Unarchive' => 'Ripristina',
    'Unlock comments' => 'Sblocca commenti',
    'Unpin' => 'Scollega',
    'Updated' => 'Aggiornato',
    'Visible also to unregistered users' => 'Visibile anche dagli utenti non registrati',
    'Visible only to you' => 'Visibile solo a te',
    'Visible to all Space members' => 'Visibile a tutti i membri dello spazio',
    'Visible to all signed in users' => 'Visibile a tutti gli utenti collegati',
    'Visible to friends of {displayName}' => 'Visibile a tutti gli amici di {displayName}',
    'Visible to you and {displayName}' => 'Visibile a te e a {displayName}',
    'Visible to your friends' => 'Visibile ai tuoi amici',
    'With attachments' => 'Con allegati',
    'You cannot block the space owner!' => 'Non puoi bloccare il proprietario dello spazio!',
    'You cannot block the user of the same container!' => 'Non puoi bloccare l\'utente.',
    'You cannot block yourself!' => 'Non puoi bloccare te stesso',
    'You do not have the permission to move this content to the given space.' => 'Non hai il permesso di spostare il contenuto nello spazio indicato.',
    'You do not have the permission to move this content.' => 'Non hai il permesso di spostare questo contenuto.',
    'Your last edit state has been saved!' => 'La tua ultima modifica è stato salvata!',
    'in' => 'in',
    'Advanced Content Search' => '',
];
